==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebValuesChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValuesChangeDetailDescriptionMetadata } from "./WebValuesChangeDetailDescriptionMetadata";
import { WebValuesChangeEventArgsDescription } from "./WebValuesChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebValuesChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebValuesChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebValuesChangeEventArgsDescriptionMetadata.a == null) {
                WebValuesChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebValuesChangeEventArgsDescriptionMetadata.c(WebValuesChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebValuesChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebValuesChangeEventArgsDescriptionMetadata.a);
            WebValuesChangeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ValuesChangeEventArgs");
            a.item("Detail", "ExportedType:WebValuesChangeDetail");
        }
        static d(a) {
            WebValuesChangeEventArgsDescriptionMetadata.b(a);
            a.ac("WebValuesChangeEventArgs", () => new WebValuesChangeEventArgsDescription());
            a.ab("WebValuesChangeEventArgs", WebValuesChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebValuesChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebValuesChangeEventArgsDescriptionMetadata, 'WebValuesChangeEventArgsDescriptionMetadata');
    WebValuesChangeEventArgsDescriptionMetadata.a = null;
    return WebValuesChangeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebValuesChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValuesChangeDetailDescriptionMetadata } from "./WebValuesChangeDetailDescriptionMetadata";
import { WebValuesChangeEventArgsDescription } from "./WebValuesChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebValuesChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebValuesChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebValuesChangeEventArgsDescriptionMetadata.a == null) {
                WebValuesChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebValuesChangeEventArgsDescriptionMetadata.c(WebValuesChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebValuesChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebValuesChangeEventArgsDescriptionMetadata.a);
            WebValuesChangeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ValuesChangeEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebValuesChangeDetail");
        }
        static d(a) {
            WebValuesChangeEventArgsDescriptionMetadata.b(a);
            a.ae("WebValuesChangeEventArgs", () => new WebValuesChangeEventArgsDescription());
            a.ad("WebValuesChangeEventArgs", WebValuesChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebValuesChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebValuesChangeEventArgsDescriptionMetadata, 'WebValuesChangeEventArgsDescriptionMetadata');
    WebValuesChangeEventArgsDescriptionMetadata.a = null;
    return WebValuesChangeEventArgsDescriptionMetadata;
})();
